﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Hangar
{
    public partial class AircraftDialog : Form
    {
        public Aircraft Aircraft { get; private set; }

        public AircraftDialog()
        {
            InitializeComponent();
        } 
          
        private void confirmButton_Click(object sender, EventArgs e)
        {
            if (ValidateChildren())
            {
                Aircraft = new Aircraft()
                    {
                        Manufacturer = manufacturerBox.Text,
                        TailNumber = tailNumberBox.Text,
                        Range = (int)rangeUpDown.Value,
                        Colour = colourButton.BackColor
                    };

                //Aircraft.Manufacturer = manufacturerBox.Text;
                //Aircraft.TailNumber = tailNumberBox.Text;
                //Aircraft.Range = (int)rangeUpDown.Value;
                //Aircraft.Colour = colourButton.BackColor;

                DialogResult = DialogResult.OK;

                Close();
            }
        }

        private void cancelButton_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;

            Close();
        }

        private void manufacturerBox_Validating(object sender, CancelEventArgs e)
        {
            if (!manufacturerBox.Items
                .Contains(manufacturerBox.Text))
            {
                errorProvider.SetError(
                    manufacturerBox,
                    "Unrecognised manufacturer.");
                e.Cancel = true;
            }
            else
            {
                errorProvider.SetError(
                    manufacturerBox, null);
                e.Cancel = false;
            }
        }

        private void tailNumberBox_Validating(object sender, CancelEventArgs e)
        {
            if ((tailNumberBox.Text.Length < 4) ||
                (tailNumberBox.Text.Length > 8))
            {
                errorProvider.SetError(
                    tailNumberBox,
                    "Tail Number must be between 4 and 8 characters long.");
                e.Cancel = true;
            }
            else if (tailNumberBox.Text
                .Any(ch => !Char.IsLetterOrDigit(ch)))
            {
                errorProvider.SetError(
                    tailNumberBox,
                    "Tail Number contains invalid character.");
                e.Cancel = true;
            }
            else
            {
                errorProvider.SetError(
                    tailNumberBox, null);
                e.Cancel = false;
            }
        }

        private void colourButton_Click(object sender, EventArgs e)
        {
            ColorDialog diag = new ColorDialog();

            if (diag.ShowDialog() == DialogResult.OK)
            {
                colourButton.BackColor = diag.Color;
            }
        }
    }
}
