﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Hangar
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();

            Paint += (sender, e) =>
                {
                    Aircraft selectedAircraft =
                        aircraftBox.SelectedItem as Aircraft;

                    if (selectedAircraft != null)
                    {
                        e.Graphics.FillRectangle(
                            new SolidBrush(selectedAircraft.Colour),
                            new Rectangle(410, 222, 50, 20));
                    }
                };
        }

        private void newToolStripMenuItem_Click(object sender, EventArgs e)
        {
            AircraftDialog diag = new AircraftDialog();

            if (diag.ShowDialog() == DialogResult.OK)
            {
                aircraftBox.Items.Add(diag.Aircraft);
            }
        }

        private void quitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void saveToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SaveFileDialog diag = new SaveFileDialog();

            diag.DefaultExt = "hdb";
            diag.Filter = "Hangar Database|*.hdb";
            diag.InitialDirectory = Environment.CurrentDirectory;
            diag.Title = "Select database file";

            if (diag.ShowDialog() == DialogResult.OK)
            {
                try
                {
                    using (StreamWriter output =
                        new StreamWriter(diag.FileName))
                    {
                        foreach (Aircraft aircraft in
                            aircraftBox.Items.Cast<Aircraft>())
                        {
                            output.WriteLine(String.Format(
                                "{0};{1};{2};{3};{4};{5};{6}",
                                aircraft.Manufacturer,
                                aircraft.TailNumber,
                                aircraft.Range,
                                aircraft.Colour.A,
                                aircraft.Colour.R,
                                aircraft.Colour.G,
                                aircraft.Colour.B));
                        }
                    }

                    //output.Close();
                }
                catch (IOException ex)
                {
                    MessageBox.Show(String.Format(
                        "Failed to save database due to {0}",
                        ex.Message), "Error");
                }
            }
        }

        private void loadToolStripMenuItem_Click(object sender, EventArgs e)
        {
            OpenFileDialog diag = new OpenFileDialog();

            diag.Filter = "Hangar Database|*.hdb";//|All Files|*.*";
            diag.InitialDirectory = Environment.CurrentDirectory;

            if (diag.ShowDialog() == DialogResult.OK)
            {
                aircraftBox.Items.Clear();

                try
                {
                    using (StreamReader input =
                        new StreamReader(diag.FileName))
                    {
                        string line;
                        while ((line = input.ReadLine()) != null)
                        {
                            string[] atributes = line.Split(';');

                            Aircraft aircraft = new Aircraft();

                            aircraft.Manufacturer = atributes[0];
                            aircraft.TailNumber = atributes[1];

                            int range;
                            if (Int32.TryParse(atributes[2], out range))
                            {
                                aircraft.Range = range;
                                aircraft.Colour = Color.FromArgb(
                                    Int32.Parse(atributes[3]),
                                    Int32.Parse(atributes[4]),
                                    Int32.Parse(atributes[5]),
                                    Int32.Parse(atributes[6]));

                                aircraftBox.Items.Add(aircraft);
                            }
                        }
                    }
                }
                catch (IOException ex)
                {
                    MessageBox.Show(String.Format(
                        "Failed to load database due to {0}",
                        ex.Message), "Error");
                }
            }
        }

        private void aircraftBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            Aircraft selectedAircraft =
                aircraftBox.SelectedItem as Aircraft;

            if (selectedAircraft == null)
            {
                manufacturerLabel.Text = "Manufacturer:";
                tailNumberLabel.Text = "Tail Number:";
                rangeLabel.Text = "Range: km";

                removeButton.Visible = false;
            }
            else
            {
                manufacturerLabel.Text = 
                    String.Format("Manufacturer: {0}",
                    selectedAircraft.Manufacturer);

                tailNumberLabel.Text =
                    String.Format("Tail Number: {0}",
                    selectedAircraft.TailNumber);

                rangeLabel.Text = String.Format(
                    "Range: {0} km",
                    selectedAircraft.Range);

                removeButton.Visible = true;
            }

            Invalidate();
        }

        private void removeButton_Click(object sender, EventArgs e)
        {
            aircraftBox.Items.Remove(aircraftBox.SelectedItem);
        }
    }
}
